import { UmiError } from '@metaplex-foundation/umi';

class ArweaveError extends UmiError {
  name = 'ArweaveError';
  constructor(message, cause) {
    super(message, 'plugin', 'Arweave', cause);
  }
}
class FailedToInitializeArweaveError extends ArweaveError {
  name = 'FailedToInitializeArweaveError';
  constructor(cause) {
    const message = 'Arweave could not be initialized. ' + 'Please check the underlying error below for more details.';
    super(message, cause);
  }
}
class FailedToConnectToArweaveAddressError extends ArweaveError {
  name = 'FailedToConnectToArweaveAddressError';
  constructor(uploadServiceUrl, paymentServiceUrl, cause) {
    const message = `Arweave could not connect to the provided addresses [${uploadServiceUrl}, ${paymentServiceUrl}]. ` + 'Please ensure the provided address is valid. Some valid addresses include: ' + '"https://upload.ardrive.io" and "https://payment.ardrive.io" for mainnet ';
    super(message, cause);
  }
}
class AssetUploadFailedError extends ArweaveError {
  name = 'AssetUploadFailedError';
  constructor(error) {
    const message = `The asset could not be uploaded to the Arweave network: ${error}`;
    super(message);
  }
}

export { ArweaveError, AssetUploadFailedError, FailedToConnectToArweaveAddressError, FailedToInitializeArweaveError };
//# sourceMappingURL=errors.mjs.map
