import { TurboAuthenticatedClient } from '@ardrive/turbo-sdk';
import { Context, Signer, SolAmount, UploaderInterface, UsdAmount } from '@metaplex-foundation/umi';
import { Connection as Web3JsConnection, PublicKey as Web3JsPublicKey, SendOptions as Web3JsSendOptions, Signer as Web3JsSigner, Transaction as Web3JsTransaction, TransactionSignature as Web3JsTransactionSignature } from '@solana/web3.js';
import BigNumber from 'bignumber.js';
export type ArweaveUploader = UploaderInterface & {
    /** Get the current Arweave Turbo client */
    arweave: () => Promise<TurboAuthenticatedClient>;
    /** Get the SOL and winc estimated price for an amount of bytes */
    getUploadPriceFromBytes: (bytes: number) => Promise<{
        solAmount: SolAmount;
        wincAmount: BigNumber;
    }>;
    /** Get the  current SOL equivalent balance from connected Arweave Bundler */
    getBalance: () => Promise<SolAmount>;
    /** Get the current Turbo Storage Credit balance from connected Arweave Bundler */
    getTurboStorageCreditBalance: () => Promise<BigNumber.Value>;
    /** Purchase non-refundable Turbo Storage Credits from the connected Arweave Bundler by transferring SOL to the Bundler's wallet */
    fund: (amount: SolAmount, skipBalanceCheck: boolean) => Promise<void>;
    /** Purchase non-refundable Turbo Storage Credits from the connected Arweave Bundler by generating a Stripe checkout session with a USD amount */
    getStripeCheckoutSession: (amount: UsdAmount) => Promise<{
        turboStorageCredits: BigNumber.Value;
        checkoutSessionUrl: string;
    }>;
};
export type ArweaveUploaderOptions = {
    solRpcUrl?: string;
    uploadServiceUrl?: string;
    paymentServiceUrl?: string;
    priceMultiplier?: number;
    payer?: Signer;
};
export type ArweaveWalletAdapter = {
    publicKey: Web3JsPublicKey | null;
    signMessage?: (message: Uint8Array) => Promise<Uint8Array>;
    signTransaction?: (transaction: Web3JsTransaction) => Promise<Web3JsTransaction>;
    signAllTransactions?: (transactions: Web3JsTransaction[]) => Promise<Web3JsTransaction[]>;
    sendTransaction: (transaction: Web3JsTransaction, connection: Web3JsConnection, options?: Web3JsSendOptions & {
        signers?: Web3JsSigner[];
    }) => Promise<Web3JsTransactionSignature>;
};
export declare function createArweaveUploader(context: Pick<Context, 'rpc' | 'payer' | 'eddsa'>, options?: ArweaveUploaderOptions): ArweaveUploader;
export declare const isArweaveUploader: (uploader: UploaderInterface) => uploader is ArweaveUploader;
